==> kcalc_23.08.5.orig.tar.xz: kcalc-23.08.5/knumber/knumber_operators.cpp <==
/*
    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "knumber_operators.h"
#include "knumber.h"
#include "knumber_base.h"
#include <config-kcalc.h>

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator+(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x += rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator-(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x -= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator*(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x *= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator/(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x /= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator%(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x %= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator&(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x &= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator|(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x |= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator^(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x ^= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator>>(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x >>= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber operator<<(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x <<= rhs;
    return x;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber abs(const KNumber &x)
{
    return x.abs();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber cbrt(const KNumber &x)
{
    return x.cbrt();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber sqrt(const KNumber &x)
{
    return x.sqrt();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber sin(const KNumber &x)
{
    return x.sin();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber cos(const KNumber &x)
{
    return x.cos();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber tan(const KNumber &x)
{
    return x.tan();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber asin(const KNumber &x)
{
    return x.asin();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber acos(const KNumber &x)
{
    return x.acos();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber tgamma(const KNumber &x)
{
    return x.tgamma();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber atan(const KNumber &x)
{
    return x.atan();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber pow(const KNumber &x, const KNumber &y)
{
    return x.pow(y);
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber factorial(const KNumber &x)
{
    return x.factorial();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber log2(const KNumber &x)
{
    return x.log2();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber floor(const KNumber &x)
{
    return x.floor();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber ceil(const KNumber &x)
{
    return x.ceil();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber log10(const KNumber &x)
{
    return x.log10();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber ln(const KNumber &x)
{
    return x.ln();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber exp2(const KNumber &x)
{
    return x.exp2();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber exp10(const KNumber &x)
{
    return x.exp10();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
KNumber exp(const KNumber &x)
{
    return x.exp();
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
bool operator==(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.value_->compare(rhs.value_) == 0;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
bool operator!=(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.value_->compare(rhs.value_) != 0;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
bool operator>=(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.value_->compare(rhs.value_) >= 0;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
bool operator<=(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.value_->compare(rhs.value_) <= 0;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
bool operator>(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.value_->compare(rhs.value_) > 0;
}

//------------------------------------------------------------------------------
// Name:
//------------------------------------------------------------------------------
bool operator<(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.value_->compare(rhs.value_) < 0;
}

==> kcalc-25.04.3.tar.xz: kcalc-25.04.3/knumber/knumber_operators.cpp <==
/*
    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "knumber_operators.h"
#include "knumber.h"
#include "knumber_base.h"
#include <config-knumber.h>

KNumber operator+(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x += rhs;
    return x;
}

KNumber operator-(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x -= rhs;
    return x;
}

KNumber operator*(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x *= rhs;
    return x;
}

KNumber operator/(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x /= rhs;
    return x;
}

KNumber operator%(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x %= rhs;
    return x;
}

KNumber operator&(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x &= rhs;
    return x;
}

KNumber operator|(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x |= rhs;
    return x;
}

KNumber operator^(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x ^= rhs;
    return x;
}

KNumber operator>>(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x >>= rhs;
    return x;
}

KNumber operator<<(const KNumber &lhs, const KNumber &rhs)
{
    KNumber x(lhs);
    x <<= rhs;
    return x;
}

KNumber abs(const KNumber &x)
{
    return x.abs();
}

KNumber cbrt(const KNumber &x)
{
    return x.cbrt();
}

KNumber sqrt(const KNumber &x)
{
    return x.sqrt();
}

KNumber sin(const KNumber &x)
{
    return x.sin();
}

KNumber cos(const KNumber &x)
{
    return x.cos();
}

KNumber tan(const KNumber &x)
{
    return x.tan();
}

KNumber asin(const KNumber &x)
{
    return x.asin();
}

KNumber acos(const KNumber &x)
{
    return x.acos();
}

KNumber tgamma(const KNumber &x)
{
    return x.tgamma();
}

KNumber atan(const KNumber &x)
{
    return x.atan();
}

KNumber pow(const KNumber &x, const KNumber &y)
{
    return x.pow(y);
}

KNumber factorial(const KNumber &x)
{
    return x.factorial();
}

KNumber log2(const KNumber &x)
{
    return x.log2();
}

KNumber floor(const KNumber &x)
{
    return x.floor();
}

KNumber ceil(const KNumber &x)
{
    return x.ceil();
}

KNumber log10(const KNumber &x)
{
    return x.log10();
}

KNumber ln(const KNumber &x)
{
    return x.ln();
}

KNumber exp2(const KNumber &x)
{
    return x.exp2();
}

KNumber exp10(const KNumber &x)
{
    return x.exp10();
}

KNumber exp(const KNumber &x)
{
    return x.exp();
}

bool operator==(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.m_value->compare(rhs.m_value) == 0;
}

bool operator!=(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.m_value->compare(rhs.m_value) != 0;
}

bool operator>=(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.m_value->compare(rhs.m_value) >= 0;
}

bool operator<=(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.m_value->compare(rhs.m_value) <= 0;
}

bool operator>(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.m_value->compare(rhs.m_value) > 0;
}

bool operator<(const KNumber &lhs, const KNumber &rhs)
{
    return lhs.m_value->compare(rhs.m_value) < 0;
}
